@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Getopt::Long with Class - ~/lib/Getopt/Class.pm
-## Version 0.1.1
+## Version 0.1.2
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/04/25
-## Modified 2020/04/26
+## Modified 2020/04/27
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -16,12 +16,13 @@ BEGIN
     use strict;
     use warnings;
     use parent qw( Module::Generic );
+    use version;
     use Getopt::Long;
     use TryCatch;
     use DateTime;
     use DateTime::Format::Strptime;
     use Scalar::Util;
-    our $VERSION = '0.1.1';
+    our $VERSION = 'v0.1.2';
 };
 
 sub init
@@ -432,7 +433,7 @@ sub exec
                     return( $self->error( "An unexpected error occurred while converting date provided for \"$k\" (", $v->{ $k }, "): $e" ) );
                 }
             }
-            elsif( $opts->{ $k } eq 'now' )
+            elsif( $opts->{ $k } eq 'now' || $opts->{ $k } eq 'today' )
             {
                 my $dt = DateTime->now( time_zone => 'local' );
                 $opts->{ $k2_dash } = $dt;
@@ -440,7 +441,7 @@ sub exec
             }
             else
             {
-                return( $self->error( "Unsuported value for date or datetime \"$k\": ", $v->{ $k }, ". Please use a unix timestamp (i.e. an integer) or an iso 8601 type like 2019-12-25" ) );
+                return( $self->error( "Unsuported value for date or datetime \"$k\": ", $v->{ $k }, ". Please use a unix timestamp (i.e. an integer) or an iso 8601 type like 2019-12-25 or 2019-12-25T07:30:10" ) );
             }
             ## Default format for stringification is the unix timestamp
             my $fmt = DateTime::Format::Strptime->new(
@@ -564,7 +565,7 @@ Getopt::Class - Extended dictionary version of Getopt::Long
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
